@@ -14,28 +14,13 @@
 # Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
-# Copyrights (C)
-# for this R-port:
-#   1999 - Diethelm Wuertz, GPL
-#   2007 - Rmetrics Foundation, GPL
-#   Diethelm Wuertz <wuertz@phys.ethz.ch>
-#   www.rmetrics.org
-# for the code accessed (or partly included) from other R-ports:
-#   see R's copyright and license files
-# for the code accessed (or partly included) from contributed R-ports
-# and other sources
-#   see Rmetrics's copyright file
-
 
 ################################################################################
 # FUNCTION:                 DESCRIPTION:
 #  holiday                   Returns a holiday date of G7 and CH
 ################################################################################
 
-
-holiday <-
-    function(year = getRmetricsOptions("currentYear"), Holiday = "Easter")
-{
+holiday <- function(year = getRmetricsOptions("currentYear"), Holiday = "Easter") {
     # A function implemented by Diethelm Wuertz
 
     # Description:
@@ -119,10 +104,15 @@ holiday <-
 
     # Determine Function:
     nHolidays = length(Holiday)
-    ans = NULL
-    for (i in 1:nHolidays) {
-        FUN = match.fun(Holiday[i])
-        ans = c(ans, as.character(FUN(year)))
+    if(nHolidays == 1) {
+        FUN = match.fun(Holiday)
+        ans = as.character(FUN(year))
+    } else {
+        ans = character(0)
+        for (i in seq_len(nHolidays)) {
+            FUN = match.fun(Holiday[[i]])
+            ans = c(ans, as.character(FUN(year)))
+        }
     }
 
     # Classify as simple integer ISO date format CCYYMMDD
@@ -134,4 +124,3 @@ holiday <-
 
 
 ################################################################################
-
