@@ -24,114 +24,81 @@
 #  kurtosis.POSIXlt          Method for objects of class POSIXlt
 ################################################################################
 
+kurtosis <- function (x, ...) {
+    ## A function implemented by Diethelm Wuertz
 
-kurtosis <-
-    function (x, ...)
-{
-    # A function implemented by Diethelm Wuertz
-
-    # FUNCTION:
-
-    # Return Value:
     UseMethod("kurtosis")
 }
 
+kurtosis.default <- function (x, na.rm = FALSE, method = c("excess", "moment", "fisher"), ...) {
+    ## A function implemented by Diethelm Wuertz
 
-# ------------------------------------------------------------------------------
+    ## Description:
+    ##   Returns the value of the kurtosis of a distribution function.
 
+    ## Details:
+    ##   Missing values can be handled.
 
-kurtosis.default <-
-    function (x, na.rm = FALSE, method = c("excess", "moment", "fisher"), ...)
-{
-    # A function implemented by Diethelm Wuertz
+    ## FUNCTION:
 
-    # Description:
-    #   Returns the value of the kurtosis of a distribution function.
-
-    # Details:
-    #   Missing values can be handled.
-
-    # FUNCTION:
-
-    # Method:
-    method = match.arg(method)
+    ## Method:
+    method <- match.arg(method)
 
     stopifnot(NCOL(x) == 1)
 
-    # Warnings:
+    ## Warnings:
     if (!is.numeric(x) && !is.complex(x) && !is.logical(x)) {
         warning("argument is not numeric or logical: returning NA")
         return(as.numeric(NA))}
 
-    # Remove NAs:
-    if (na.rm) x = x[!is.na(x)]
+    ## Remove NAs:
+    if (na.rm) x <- x[!is.na(x)]
 
-    # Kurtosis:
-    n = length(x)
-    if (is.integer(x)) x = as.numeric(x)
+    ## Kurtosis:
+    n <- length(x)
+    if (is.integer(x)) x <- as.numeric(x)
     if (method == "excess") {
-        kurtosis = sum((x-mean(x))^4/as.numeric(var(x))^2)/length(x) - 3
+        kurtosis <- sum((x-mean(x))^4/as.numeric(var(x))^2)/length(x) - 3
     }
     if (method == "moment") {
-        kurtosis = sum((x-mean(x))^4/as.numeric(var(x))^2)/length(x)
+        kurtosis <- sum((x-mean(x))^4/as.numeric(var(x))^2)/length(x)
     }
     if (method == "fisher") {
-        kurtosis = ((n+1)*(n-1)*((sum(x^4)/n)/(sum(x^2)/n)^2 -
-            (3*(n-1))/(n+1)))/((n-2)*(n-3))
+        kurtosis <- ((n+1)*(n-1)*((sum(x^4)/n)/(sum(x^2)/n)^2 - (3*(n-1))/(n+1))) /
+            ((n-2)*(n-3))
     }
 
-    # Add Control Attribute:
+    ## Add Control Attribute:
     attr(kurtosis, "method") <- method
 
-    # Return Value:
+    ## Return Value:
     kurtosis
 }
 
+kurtosis.data.frame <- function (x, na.rm = FALSE, method = c("excess", "moment", "fisher"), ...) {
+    ## A function implemented by Diethelm Wuertz
+    ## Amended by Georgi N. Boshnakov to set attribute 'method' as documented.
+    ## (changed the signature from (x, ...) to make this straightforward)
 
-# ------------------------------------------------------------------------------
+    ## FUNCTION:
+    method <- match.arg(method)
 
-
-kurtosis.data.frame <-
-    function (x, ...)
-{
-    # A function implemented by Diethelm Wuertz
-
-    # FUNCTION:
-
-    # Return Value:
-    sapply(x, kurtosis, ...)
+    ## Return Value:
+    structure(sapply(x, kurtosis, na.rm = na.rm, method = method, ...),
+              method = method)
 }
 
+kurtosis.POSIXct <- function (x, ...) {
+    ## A function implemented by Diethelm Wuertz
 
-# ------------------------------------------------------------------------------
-
-
-kurtosis.POSIXct <-
-    function (x, ...)
-{
-    # A function implemented by Diethelm Wuertz
-
-    # FUNCTION:
-
-    # Return Value:
     structure(kurtosis(unclass(x), ...), class = oldClass(x))
 }
 
+kurtosis.POSIXlt <- function (x, ...) {
+    ## A function implemented by Diethelm Wuertz
 
-# ------------------------------------------------------------------------------
-
-
-kurtosis.POSIXlt <-
-    function (x, ...)
-{
-    # A function implemented by Diethelm Wuertz
-
-    # FUNCTION:
-
-    # Return Value:
     as.POSIXlt(kurtosis(as.POSIXct(x), ...))
 }
 
 
 ################################################################################
-
